# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_compute_instance.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1egcp/gcp_compute_instance.proto\x12 oak9.tython.gcp.compute_instance\x1a\x13shared/shared.proto\"i\n\'ComputeInstanceXAdvancedMachineFeatures\x12$\n\x1c\x65nable_nested_virtualization\x18\x01 \x01(\x08\x12\x18\n\x10threads_per_core\x18\x02 \x01(\x01\"\xb1\x01\n\x1c\x43omputeInstanceXAttachedDisk\x12\x13\n\x0b\x64\x65vice_name\x18\x01 \x01(\t\x12\x1f\n\x17\x64isk_encryption_key_raw\x18\x02 \x01(\t\x12\"\n\x1a\x64isk_encryption_key_sha256\x18\x03 \x01(\t\x12\x19\n\x11kms_key_self_link\x18\x04 \x01(\t\x12\x0c\n\x04mode\x18\x05 \x01(\t\x12\x0e\n\x06source\x18\x06 \x01(\t\"\xee\x01\n)ComputeInstanceXBootDiskXInitializeParams\x12\r\n\x05image\x18\x01 \x01(\t\x12g\n\x06labels\x18\x02 \x03(\x0b\x32W.oak9.tython.gcp.compute_instance.ComputeInstanceXBootDiskXInitializeParams.LabelsEntry\x12\x0c\n\x04size\x18\x03 \x01(\x01\x12\x0c\n\x04type\x18\x04 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xaa\x02\n\x18\x43omputeInstanceXBootDisk\x12\x13\n\x0b\x61uto_delete\x18\x01 \x01(\x08\x12\x13\n\x0b\x64\x65vice_name\x18\x02 \x01(\t\x12\x1f\n\x17\x64isk_encryption_key_raw\x18\x03 \x01(\t\x12\"\n\x1a\x64isk_encryption_key_sha256\x18\x04 \x01(\t\x12\x19\n\x11kms_key_self_link\x18\x05 \x01(\t\x12\x0c\n\x04mode\x18\x06 \x01(\t\x12\x0e\n\x06source\x18\x07 \x01(\t\x12\x66\n\x11initialize_params\x18\x08 \x01(\x0b\x32K.oak9.tython.gcp.compute_instance.ComputeInstanceXBootDiskXInitializeParams\"Q\n*ComputeInstanceXConfidentialInstanceConfig\x12#\n\x1b\x65nable_confidential_compute\x18\x01 \x01(\x08\"u\n-ComputeInstanceXNetworkInterfaceXAccessConfig\x12\x0e\n\x06nat_ip\x18\x01 \x01(\t\x12\x14\n\x0cnetwork_tier\x18\x02 \x01(\t\x12\x1e\n\x16public_ptr_domain_name\x18\x03 \x01(\t\"e\n-ComputeInstanceXNetworkInterfaceXAliasIpRange\x12\x15\n\rip_cidr_range\x18\x01 \x01(\t\x12\x1d\n\x15subnetwork_range_name\x18\x02 \x01(\t\"\xa5\x01\n1ComputeInstanceXNetworkInterfaceXIpv6AccessConfig\x12\x15\n\rexternal_ipv6\x18\x01 \x01(\t\x12#\n\x1b\x65xternal_ipv6_prefix_length\x18\x02 \x01(\t\x12\x14\n\x0cnetwork_tier\x18\x03 \x01(\t\x12\x1e\n\x16public_ptr_domain_name\x18\x04 \x01(\t\"\x9c\x04\n ComputeInstanceXNetworkInterface\x12\x18\n\x10ipv6_access_type\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07network\x18\x03 \x01(\t\x12\x12\n\nnetwork_ip\x18\x04 \x01(\t\x12\x10\n\x08nic_type\x18\x05 \x01(\t\x12\x13\n\x0bqueue_count\x18\x06 \x01(\x01\x12\x12\n\nstack_type\x18\x07 \x01(\t\x12\x12\n\nsubnetwork\x18\x08 \x01(\t\x12\x1a\n\x12subnetwork_project\x18\t \x01(\t\x12\x66\n\raccess_config\x18\n \x03(\x0b\x32O.oak9.tython.gcp.compute_instance.ComputeInstanceXNetworkInterfaceXAccessConfig\x12g\n\x0e\x61lias_ip_range\x18\x0b \x03(\x0b\x32O.oak9.tython.gcp.compute_instance.ComputeInstanceXNetworkInterfaceXAliasIpRange\x12o\n\x12ipv6_access_config\x18\x0c \x03(\x0b\x32S.oak9.tython.gcp.compute_instance.ComputeInstanceXNetworkInterfaceXIpv6AccessConfig\"V\n7ComputeInstanceXReservationAffinityXSpecificReservation\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x0e\n\x06values\x18\x02 \x03(\t\"\xac\x01\n#ComputeInstanceXReservationAffinity\x12\x0c\n\x04type\x18\x01 \x01(\t\x12w\n\x14specific_reservation\x18\x02 \x01(\x0b\x32Y.oak9.tython.gcp.compute_instance.ComputeInstanceXReservationAffinityXSpecificReservation\"Z\n)ComputeInstanceXSchedulingXNodeAffinities\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x10\n\x08operator\x18\x02 \x01(\t\x12\x0e\n\x06values\x18\x03 \x03(\t\"\xa7\x02\n\x1a\x43omputeInstanceXScheduling\x12\x19\n\x11\x61utomatic_restart\x18\x01 \x01(\x08\x12#\n\x1binstance_termination_action\x18\x02 \x01(\t\x12\x15\n\rmin_node_cpus\x18\x03 \x01(\x01\x12\x1b\n\x13on_host_maintenance\x18\x04 \x01(\t\x12\x13\n\x0bpreemptible\x18\x05 \x01(\x08\x12\x1a\n\x12provisioning_model\x18\x06 \x01(\t\x12\x64\n\x0fnode_affinities\x18\x07 \x03(\x0b\x32K.oak9.tython.gcp.compute_instance.ComputeInstanceXSchedulingXNodeAffinities\"0\n\x1b\x43omputeInstanceXScratchDisk\x12\x11\n\tinterface\x18\x01 \x01(\t\"?\n\x1e\x43omputeInstanceXServiceAccount\x12\r\n\x05\x65mail\x18\x01 \x01(\t\x12\x0e\n\x06scopes\x18\x02 \x03(\t\"~\n&ComputeInstanceXShieldedInstanceConfig\x12#\n\x1b\x65nable_integrity_monitoring\x18\x01 \x01(\x08\x12\x1a\n\x12\x65nable_secure_boot\x18\x02 \x01(\x08\x12\x13\n\x0b\x65nable_vtpm\x18\x03 \x01(\x08\"J\n\x18\x43omputeInstanceXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xfc\x0f\n\x0f\x43omputeInstance\x12!\n\x19\x61llow_stopping_for_update\x18\x01 \x01(\x08\x12\x16\n\x0e\x63\x61n_ip_forward\x18\x02 \x01(\x08\x12\x14\n\x0c\x63pu_platform\x18\x03 \x01(\t\x12\x16\n\x0e\x63urrent_status\x18\x04 \x01(\t\x12\x1b\n\x13\x64\x65letion_protection\x18\x05 \x01(\x08\x12\x13\n\x0b\x64\x65scription\x18\x06 \x01(\t\x12\x16\n\x0e\x64\x65sired_status\x18\x07 \x01(\t\x12\x16\n\x0e\x65nable_display\x18\x08 \x01(\x08\x12\x62\n\x11guest_accelerator\x18\t \x03(\x0b\x32G.oak9.tython.gcp.compute_instance.ComputeInstance.GuestAcceleratorEntry\x12\x10\n\x08hostname\x18\n \x01(\t\x12\n\n\x02id\x18\x0b \x01(\t\x12\x13\n\x0binstance_id\x18\x0c \x01(\t\x12\x19\n\x11label_fingerprint\x18\r \x01(\t\x12M\n\x06labels\x18\x0e \x03(\x0b\x32=.oak9.tython.gcp.compute_instance.ComputeInstance.LabelsEntry\x12\x14\n\x0cmachine_type\x18\x0f \x01(\t\x12Q\n\x08metadata\x18\x10 \x03(\x0b\x32?.oak9.tython.gcp.compute_instance.ComputeInstance.MetadataEntry\x12\x1c\n\x14metadata_fingerprint\x18\x11 \x01(\t\x12\x1f\n\x17metadata_startup_script\x18\x12 \x01(\t\x12\x18\n\x10min_cpu_platform\x18\x13 \x01(\t\x12\x0c\n\x04name\x18\x14 \x01(\t\x12\x0f\n\x07project\x18\x15 \x01(\t\x12\x19\n\x11resource_policies\x18\x16 \x03(\t\x12\x11\n\tself_link\x18\x17 \x01(\t\x12\x0c\n\x04tags\x18\x18 \x03(\t\x12\x18\n\x10tags_fingerprint\x18\x19 \x01(\t\x12\x0c\n\x04zone\x18\x1a \x01(\t\x12l\n\x19\x61\x64vanced_machine_features\x18\x1b \x01(\x0b\x32I.oak9.tython.gcp.compute_instance.ComputeInstanceXAdvancedMachineFeatures\x12U\n\rattached_disk\x18\x1c \x03(\x0b\x32>.oak9.tython.gcp.compute_instance.ComputeInstanceXAttachedDisk\x12M\n\tboot_disk\x18\x1d \x01(\x0b\x32:.oak9.tython.gcp.compute_instance.ComputeInstanceXBootDisk\x12r\n\x1c\x63onfidential_instance_config\x18\x1e \x01(\x0b\x32L.oak9.tython.gcp.compute_instance.ComputeInstanceXConfidentialInstanceConfig\x12]\n\x11network_interface\x18\x1f \x03(\x0b\x32\x42.oak9.tython.gcp.compute_instance.ComputeInstanceXNetworkInterface\x12\x63\n\x14reservation_affinity\x18  \x01(\x0b\x32\x45.oak9.tython.gcp.compute_instance.ComputeInstanceXReservationAffinity\x12P\n\nscheduling\x18! \x01(\x0b\x32<.oak9.tython.gcp.compute_instance.ComputeInstanceXScheduling\x12S\n\x0cscratch_disk\x18\" \x03(\x0b\x32=.oak9.tython.gcp.compute_instance.ComputeInstanceXScratchDisk\x12Y\n\x0fservice_account\x18# \x01(\x0b\x32@.oak9.tython.gcp.compute_instance.ComputeInstanceXServiceAccount\x12j\n\x18shielded_instance_config\x18$ \x01(\x0b\x32H.oak9.tython.gcp.compute_instance.ComputeInstanceXShieldedInstanceConfig\x12L\n\x08timeouts\x18% \x01(\x0b\x32:.oak9.tython.gcp.compute_instance.ComputeInstanceXTimeouts\x12\x37\n\rresource_info\x18& \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a\x37\n\x15GuestAcceleratorEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"u\n3ComputeInstanceFromTemplateXAdvancedMachineFeatures\x12$\n\x1c\x65nable_nested_virtualization\x18\x01 \x01(\x08\x12\x18\n\x10threads_per_core\x18\x02 \x01(\x01\"\x86\x02\n5ComputeInstanceFromTemplateXBootDiskXInitializeParams\x12\r\n\x05image\x18\x01 \x01(\t\x12s\n\x06labels\x18\x02 \x03(\x0b\x32\x63.oak9.tython.gcp.compute_instance.ComputeInstanceFromTemplateXBootDiskXInitializeParams.LabelsEntry\x12\x0c\n\x04size\x18\x03 \x01(\x01\x12\x0c\n\x04type\x18\x04 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xc2\x02\n$ComputeInstanceFromTemplateXBootDisk\x12\x13\n\x0b\x61uto_delete\x18\x01 \x01(\x08\x12\x13\n\x0b\x64\x65vice_name\x18\x02 \x01(\t\x12\x1f\n\x17\x64isk_encryption_key_raw\x18\x03 \x01(\t\x12\"\n\x1a\x64isk_encryption_key_sha256\x18\x04 \x01(\t\x12\x19\n\x11kms_key_self_link\x18\x05 \x01(\t\x12\x0c\n\x04mode\x18\x06 \x01(\t\x12\x0e\n\x06source\x18\x07 \x01(\t\x12r\n\x11initialize_params\x18\x08 \x01(\x0b\x32W.oak9.tython.gcp.compute_instance.ComputeInstanceFromTemplateXBootDiskXInitializeParams\"]\n6ComputeInstanceFromTemplateXConfidentialInstanceConfig\x12#\n\x1b\x65nable_confidential_compute\x18\x01 \x01(\x08\"\xb1\x01\n=ComputeInstanceFromTemplateXNetworkInterfaceXIpv6AccessConfig\x12\x15\n\rexternal_ipv6\x18\x01 \x01(\t\x12#\n\x1b\x65xternal_ipv6_prefix_length\x18\x02 \x01(\t\x12\x14\n\x0cnetwork_tier\x18\x03 \x01(\t\x12\x1e\n\x16public_ptr_domain_name\x18\x04 \x01(\t\"\xc0\x05\n,ComputeInstanceFromTemplateXNetworkInterface\x12w\n\raccess_config\x18\x01 \x03(\x0b\x32`.oak9.tython.gcp.compute_instance.ComputeInstanceFromTemplateXNetworkInterface.AccessConfigEntry\x12x\n\x0e\x61lias_ip_range\x18\x02 \x03(\x0b\x32`.oak9.tython.gcp.compute_instance.ComputeInstanceFromTemplateXNetworkInterface.AliasIpRangeEntry\x12\x18\n\x10ipv6_access_type\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0f\n\x07network\x18\x05 \x01(\t\x12\x12\n\nnetwork_ip\x18\x06 \x01(\t\x12\x10\n\x08nic_type\x18\x07 \x01(\t\x12\x13\n\x0bqueue_count\x18\x08 \x01(\x01\x12\x12\n\nstack_type\x18\t \x01(\t\x12\x12\n\nsubnetwork\x18\n \x01(\t\x12\x1a\n\x12subnetwork_project\x18\x0b \x01(\t\x12{\n\x12ipv6_access_config\x18\x0c \x03(\x0b\x32_.oak9.tython.gcp.compute_instance.ComputeInstanceFromTemplateXNetworkInterfaceXIpv6AccessConfig\x1a\x33\n\x11\x41\x63\x63\x65ssConfigEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x33\n\x11\x41liasIpRangeEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"b\nCComputeInstanceFromTemplateXReservationAffinityXSpecificReservation\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x0e\n\x06values\x18\x02 \x03(\t\"\xc5\x01\n/ComputeInstanceFromTemplateXReservationAffinity\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x83\x01\n\x14specific_reservation\x18\x02 \x01(\x0b\x32\x65.oak9.tython.gcp.compute_instance.ComputeInstanceFromTemplateXReservationAffinityXSpecificReservation\"f\n5ComputeInstanceFromTemplateXSchedulingXNodeAffinities\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x10\n\x08operator\x18\x02 \x01(\t\x12\x0e\n\x06values\x18\x03 \x03(\t\"\xbf\x02\n&ComputeInstanceFromTemplateXScheduling\x12\x19\n\x11\x61utomatic_restart\x18\x01 \x01(\x08\x12#\n\x1binstance_termination_action\x18\x02 \x01(\t\x12\x15\n\rmin_node_cpus\x18\x03 \x01(\x01\x12\x1b\n\x13on_host_maintenance\x18\x04 \x01(\t\x12\x13\n\x0bpreemptible\x18\x05 \x01(\x08\x12\x1a\n\x12provisioning_model\x18\x06 \x01(\t\x12p\n\x0fnode_affinities\x18\x07 \x03(\x0b\x32W.oak9.tython.gcp.compute_instance.ComputeInstanceFromTemplateXSchedulingXNodeAffinities\"\x8a\x01\n2ComputeInstanceFromTemplateXShieldedInstanceConfig\x12#\n\x1b\x65nable_integrity_monitoring\x18\x01 \x01(\x08\x12\x1a\n\x12\x65nable_secure_boot\x18\x02 \x01(\x08\x12\x13\n\x0b\x65nable_vtpm\x18\x03 \x01(\x08\"V\n$ComputeInstanceFromTemplateXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\x81\x13\n\x1b\x43omputeInstanceFromTemplate\x12!\n\x19\x61llow_stopping_for_update\x18\x01 \x01(\x08\x12\x66\n\rattached_disk\x18\x02 \x03(\x0b\x32O.oak9.tython.gcp.compute_instance.ComputeInstanceFromTemplate.AttachedDiskEntry\x12\x16\n\x0e\x63\x61n_ip_forward\x18\x03 \x01(\x08\x12\x14\n\x0c\x63pu_platform\x18\x04 \x01(\t\x12\x16\n\x0e\x63urrent_status\x18\x05 \x01(\t\x12\x1b\n\x13\x64\x65letion_protection\x18\x06 \x01(\x08\x12\x13\n\x0b\x64\x65scription\x18\x07 \x01(\t\x12\x16\n\x0e\x64\x65sired_status\x18\x08 \x01(\t\x12\x16\n\x0e\x65nable_display\x18\t \x01(\x08\x12n\n\x11guest_accelerator\x18\n \x03(\x0b\x32S.oak9.tython.gcp.compute_instance.ComputeInstanceFromTemplate.GuestAcceleratorEntry\x12\x10\n\x08hostname\x18\x0b \x01(\t\x12\n\n\x02id\x18\x0c \x01(\t\x12\x13\n\x0binstance_id\x18\r \x01(\t\x12\x19\n\x11label_fingerprint\x18\x0e \x01(\t\x12Y\n\x06labels\x18\x0f \x03(\x0b\x32I.oak9.tython.gcp.compute_instance.ComputeInstanceFromTemplate.LabelsEntry\x12\x14\n\x0cmachine_type\x18\x10 \x01(\t\x12]\n\x08metadata\x18\x11 \x03(\x0b\x32K.oak9.tython.gcp.compute_instance.ComputeInstanceFromTemplate.MetadataEntry\x12\x1c\n\x14metadata_fingerprint\x18\x12 \x01(\t\x12\x1f\n\x17metadata_startup_script\x18\x13 \x01(\t\x12\x18\n\x10min_cpu_platform\x18\x14 \x01(\t\x12\x0c\n\x04name\x18\x15 \x01(\t\x12\x0f\n\x07project\x18\x16 \x01(\t\x12\x19\n\x11resource_policies\x18\x17 \x03(\t\x12\x64\n\x0cscratch_disk\x18\x18 \x03(\x0b\x32N.oak9.tython.gcp.compute_instance.ComputeInstanceFromTemplate.ScratchDiskEntry\x12\x11\n\tself_link\x18\x19 \x01(\t\x12j\n\x0fservice_account\x18\x1a \x03(\x0b\x32Q.oak9.tython.gcp.compute_instance.ComputeInstanceFromTemplate.ServiceAccountEntry\x12 \n\x18source_instance_template\x18\x1b \x01(\t\x12\x0c\n\x04tags\x18\x1c \x03(\t\x12\x18\n\x10tags_fingerprint\x18\x1d \x01(\t\x12\x0c\n\x04zone\x18\x1e \x01(\t\x12x\n\x19\x61\x64vanced_machine_features\x18\x1f \x01(\x0b\x32U.oak9.tython.gcp.compute_instance.ComputeInstanceFromTemplateXAdvancedMachineFeatures\x12Y\n\tboot_disk\x18  \x01(\x0b\x32\x46.oak9.tython.gcp.compute_instance.ComputeInstanceFromTemplateXBootDisk\x12~\n\x1c\x63onfidential_instance_config\x18! \x01(\x0b\x32X.oak9.tython.gcp.compute_instance.ComputeInstanceFromTemplateXConfidentialInstanceConfig\x12i\n\x11network_interface\x18\" \x03(\x0b\x32N.oak9.tython.gcp.compute_instance.ComputeInstanceFromTemplateXNetworkInterface\x12o\n\x14reservation_affinity\x18# \x01(\x0b\x32Q.oak9.tython.gcp.compute_instance.ComputeInstanceFromTemplateXReservationAffinity\x12\\\n\nscheduling\x18$ \x01(\x0b\x32H.oak9.tython.gcp.compute_instance.ComputeInstanceFromTemplateXScheduling\x12v\n\x18shielded_instance_config\x18% \x01(\x0b\x32T.oak9.tython.gcp.compute_instance.ComputeInstanceFromTemplateXShieldedInstanceConfig\x12X\n\x08timeouts\x18& \x01(\x0b\x32\x46.oak9.tython.gcp.compute_instance.ComputeInstanceFromTemplateXTimeouts\x12\x37\n\rresource_info\x18\' \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a\x33\n\x11\x41ttachedDiskEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x37\n\x15GuestAcceleratorEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x32\n\x10ScratchDiskEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x35\n\x13ServiceAccountEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"<\n\x1e\x43omputeInstanceGroupXNamedPort\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\x01\"O\n\x1d\x43omputeInstanceGroupXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\x8b\x03\n\x14\x43omputeInstanceGroup\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x11\n\tinstances\x18\x03 \x03(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0f\n\x07network\x18\x05 \x01(\t\x12\x0f\n\x07project\x18\x06 \x01(\t\x12\x11\n\tself_link\x18\x07 \x01(\t\x12\x0c\n\x04size\x18\x08 \x01(\x01\x12\x0c\n\x04zone\x18\t \x01(\t\x12T\n\nnamed_port\x18\n \x03(\x0b\x32@.oak9.tython.gcp.compute_instance.ComputeInstanceGroupXNamedPort\x12Q\n\x08timeouts\x18\x0b \x01(\x0b\x32?.oak9.tython.gcp.compute_instance.ComputeInstanceGroupXTimeouts\x12\x37\n\rresource_info\x18\x0c \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"b\n/ComputeInstanceGroupManagerXAutoHealingPolicies\x12\x14\n\x0chealth_check\x18\x01 \x01(\t\x12\x19\n\x11initial_delay_sec\x18\x02 \x01(\x01\"C\n%ComputeInstanceGroupManagerXNamedPort\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\x01\"T\n(ComputeInstanceGroupManagerXStatefulDisk\x12\x13\n\x0b\x64\x65lete_rule\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65vice_name\x18\x02 \x01(\t\"V\n$ComputeInstanceGroupManagerXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\x88\x02\n(ComputeInstanceGroupManagerXUpdatePolicy\x12\x17\n\x0fmax_surge_fixed\x18\x01 \x01(\x01\x12\x19\n\x11max_surge_percent\x18\x02 \x01(\x01\x12\x1d\n\x15max_unavailable_fixed\x18\x03 \x01(\x01\x12\x1f\n\x17max_unavailable_percent\x18\x04 \x01(\x01\x12\x16\n\x0eminimal_action\x18\x05 \x01(\t\x12&\n\x1emost_disruptive_allowed_action\x18\x06 \x01(\t\x12\x1a\n\x12replacement_method\x18\x07 \x01(\t\x12\x0c\n\x04type\x18\x08 \x01(\t\"P\n.ComputeInstanceGroupManagerXVersionXTargetSize\x12\r\n\x05\x66ixed\x18\x01 \x01(\x01\x12\x0f\n\x07percent\x18\x02 \x01(\x01\"\xb5\x01\n#ComputeInstanceGroupManagerXVersion\x12\x19\n\x11instance_template\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x65\n\x0btarget_size\x18\x03 \x01(\x0b\x32P.oak9.tython.gcp.compute_instance.ComputeInstanceGroupManagerXVersionXTargetSize\"\xce\x08\n\x1b\x43omputeInstanceGroupManager\x12\x1a\n\x12\x62\x61se_instance_name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x13\n\x0b\x66ingerprint\x18\x03 \x01(\t\x12\n\n\x02id\x18\x04 \x01(\t\x12\x16\n\x0einstance_group\x18\x05 \x01(\t\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x11\n\toperation\x18\x07 \x01(\t\x12\x0f\n\x07project\x18\x08 \x01(\t\x12\x11\n\tself_link\x18\t \x01(\t\x12Y\n\x06status\x18\n \x03(\x0b\x32I.oak9.tython.gcp.compute_instance.ComputeInstanceGroupManager.StatusEntry\x12\x14\n\x0ctarget_pools\x18\x0b \x03(\t\x12\x13\n\x0btarget_size\x18\x0c \x01(\x01\x12\x1a\n\x12wait_for_instances\x18\r \x01(\x08\x12!\n\x19wait_for_instances_status\x18\x0e \x01(\t\x12\x0c\n\x04zone\x18\x0f \x01(\t\x12p\n\x15\x61uto_healing_policies\x18\x10 \x01(\x0b\x32Q.oak9.tython.gcp.compute_instance.ComputeInstanceGroupManagerXAutoHealingPolicies\x12[\n\nnamed_port\x18\x11 \x03(\x0b\x32G.oak9.tython.gcp.compute_instance.ComputeInstanceGroupManagerXNamedPort\x12\x61\n\rstateful_disk\x18\x12 \x03(\x0b\x32J.oak9.tython.gcp.compute_instance.ComputeInstanceGroupManagerXStatefulDisk\x12X\n\x08timeouts\x18\x13 \x01(\x0b\x32\x46.oak9.tython.gcp.compute_instance.ComputeInstanceGroupManagerXTimeouts\x12\x61\n\rupdate_policy\x18\x14 \x01(\x0b\x32J.oak9.tython.gcp.compute_instance.ComputeInstanceGroupManagerXUpdatePolicy\x12V\n\x07version\x18\x15 \x03(\x0b\x32\x45.oak9.tython.gcp.compute_instance.ComputeInstanceGroupManagerXVersion\x12\x37\n\rresource_info\x18\x16 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bStatusEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"H\n&ComputeInstanceGroupNamedPortXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\"\x8a\x02\n\x1d\x43omputeInstanceGroupNamedPort\x12\r\n\x05group\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0c\n\x04port\x18\x04 \x01(\x01\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x0c\n\x04zone\x18\x06 \x01(\t\x12Z\n\x08timeouts\x18\x07 \x01(\x0b\x32H.oak9.tython.gcp.compute_instance.ComputeInstanceGroupNamedPortXTimeouts\x12\x37\n\rresource_info\x18\x08 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"]\n#ComputeInstanceIamBindingXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\x9d\x02\n\x19\x43omputeInstanceIamBinding\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x15\n\rinstance_name\x18\x03 \x01(\t\x12\x0f\n\x07members\x18\x04 \x03(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x0c\n\x04role\x18\x06 \x01(\t\x12\x0c\n\x04zone\x18\x07 \x01(\t\x12X\n\tcondition\x18\x08 \x01(\x0b\x32\x45.oak9.tython.gcp.compute_instance.ComputeInstanceIamBindingXCondition\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\\\n\"ComputeInstanceIamMemberXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\x9a\x02\n\x18\x43omputeInstanceIamMember\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x15\n\rinstance_name\x18\x03 \x01(\t\x12\x0e\n\x06member\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x0c\n\x04role\x18\x06 \x01(\t\x12\x0c\n\x04zone\x18\x07 \x01(\t\x12W\n\tcondition\x18\x08 \x01(\x0b\x32\x44.oak9.tython.gcp.compute_instance.ComputeInstanceIamMemberXCondition\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xb8\x01\n\x18\x43omputeInstanceIamPolicy\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x15\n\rinstance_name\x18\x03 \x01(\t\x12\x13\n\x0bpolicy_data\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x0c\n\x04zone\x18\x06 \x01(\t\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"q\n/ComputeInstanceTemplateXAdvancedMachineFeatures\x12$\n\x1c\x65nable_nested_virtualization\x18\x01 \x01(\x08\x12\x18\n\x10threads_per_core\x18\x02 \x01(\x01\"Y\n2ComputeInstanceTemplateXConfidentialInstanceConfig\x12#\n\x1b\x65nable_confidential_compute\x18\x01 \x01(\x08\"K\n.ComputeInstanceTemplateXDiskXDiskEncryptionKey\x12\x19\n\x11kms_key_self_link\x18\x01 \x01(\t\"\xfc\x03\n\x1c\x43omputeInstanceTemplateXDisk\x12\x13\n\x0b\x61uto_delete\x18\x01 \x01(\x08\x12\x0c\n\x04\x62oot\x18\x02 \x01(\x08\x12\x13\n\x0b\x64\x65vice_name\x18\x03 \x01(\t\x12\x11\n\tdisk_name\x18\x04 \x01(\t\x12\x14\n\x0c\x64isk_size_gb\x18\x05 \x01(\x01\x12\x11\n\tdisk_type\x18\x06 \x01(\t\x12\x11\n\tinterface\x18\x07 \x01(\t\x12Z\n\x06labels\x18\x08 \x03(\x0b\x32J.oak9.tython.gcp.compute_instance.ComputeInstanceTemplateXDisk.LabelsEntry\x12\x0c\n\x04mode\x18\t \x01(\t\x12\x19\n\x11resource_policies\x18\n \x03(\t\x12\x0e\n\x06source\x18\x0b \x01(\t\x12\x14\n\x0csource_image\x18\x0c \x01(\t\x12\x0c\n\x04type\x18\r \x01(\t\x12m\n\x13\x64isk_encryption_key\x18\x0e \x01(\x0b\x32P.oak9.tython.gcp.compute_instance.ComputeInstanceTemplateXDiskXDiskEncryptionKey\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"G\n(ComputeInstanceTemplateXGuestAccelerator\x12\r\n\x05\x63ount\x18\x01 \x01(\x01\x12\x0c\n\x04type\x18\x02 \x01(\t\"}\n5ComputeInstanceTemplateXNetworkInterfaceXAccessConfig\x12\x0e\n\x06nat_ip\x18\x01 \x01(\t\x12\x14\n\x0cnetwork_tier\x18\x02 \x01(\t\x12\x1e\n\x16public_ptr_domain_name\x18\x03 \x01(\t\"m\n5ComputeInstanceTemplateXNetworkInterfaceXAliasIpRange\x12\x15\n\rip_cidr_range\x18\x01 \x01(\t\x12\x1d\n\x15subnetwork_range_name\x18\x02 \x01(\t\"\xad\x01\n9ComputeInstanceTemplateXNetworkInterfaceXIpv6AccessConfig\x12\x15\n\rexternal_ipv6\x18\x01 \x01(\t\x12#\n\x1b\x65xternal_ipv6_prefix_length\x18\x02 \x01(\t\x12\x14\n\x0cnetwork_tier\x18\x03 \x01(\t\x12\x1e\n\x16public_ptr_domain_name\x18\x04 \x01(\t\"\xbc\x04\n(ComputeInstanceTemplateXNetworkInterface\x12\x18\n\x10ipv6_access_type\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07network\x18\x03 \x01(\t\x12\x12\n\nnetwork_ip\x18\x04 \x01(\t\x12\x10\n\x08nic_type\x18\x05 \x01(\t\x12\x13\n\x0bqueue_count\x18\x06 \x01(\x01\x12\x12\n\nstack_type\x18\x07 \x01(\t\x12\x12\n\nsubnetwork\x18\x08 \x01(\t\x12\x1a\n\x12subnetwork_project\x18\t \x01(\t\x12n\n\raccess_config\x18\n \x03(\x0b\x32W.oak9.tython.gcp.compute_instance.ComputeInstanceTemplateXNetworkInterfaceXAccessConfig\x12o\n\x0e\x61lias_ip_range\x18\x0b \x03(\x0b\x32W.oak9.tython.gcp.compute_instance.ComputeInstanceTemplateXNetworkInterfaceXAliasIpRange\x12w\n\x12ipv6_access_config\x18\x0c \x03(\x0b\x32[.oak9.tython.gcp.compute_instance.ComputeInstanceTemplateXNetworkInterfaceXIpv6AccessConfig\"^\n?ComputeInstanceTemplateXReservationAffinityXSpecificReservation\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x0e\n\x06values\x18\x02 \x03(\t\"\xbc\x01\n+ComputeInstanceTemplateXReservationAffinity\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x7f\n\x14specific_reservation\x18\x02 \x01(\x0b\x32\x61.oak9.tython.gcp.compute_instance.ComputeInstanceTemplateXReservationAffinityXSpecificReservation\"b\n1ComputeInstanceTemplateXSchedulingXNodeAffinities\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x10\n\x08operator\x18\x02 \x01(\t\x12\x0e\n\x06values\x18\x03 \x03(\t\"\xb7\x02\n\"ComputeInstanceTemplateXScheduling\x12\x19\n\x11\x61utomatic_restart\x18\x01 \x01(\x08\x12#\n\x1binstance_termination_action\x18\x02 \x01(\t\x12\x15\n\rmin_node_cpus\x18\x03 \x01(\x01\x12\x1b\n\x13on_host_maintenance\x18\x04 \x01(\t\x12\x13\n\x0bpreemptible\x18\x05 \x01(\x08\x12\x1a\n\x12provisioning_model\x18\x06 \x01(\t\x12l\n\x0fnode_affinities\x18\x07 \x03(\x0b\x32S.oak9.tython.gcp.compute_instance.ComputeInstanceTemplateXSchedulingXNodeAffinities\"G\n&ComputeInstanceTemplateXServiceAccount\x12\r\n\x05\x65mail\x18\x01 \x01(\t\x12\x0e\n\x06scopes\x18\x02 \x03(\t\"\x86\x01\n.ComputeInstanceTemplateXShieldedInstanceConfig\x12#\n\x1b\x65nable_integrity_monitoring\x18\x01 \x01(\x08\x12\x1a\n\x12\x65nable_secure_boot\x18\x02 \x01(\x08\x12\x13\n\x0b\x65nable_vtpm\x18\x03 \x01(\x08\"B\n ComputeInstanceTemplateXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\"\xab\r\n\x17\x43omputeInstanceTemplate\x12\x16\n\x0e\x63\x61n_ip_forward\x18\x01 \x01(\x08\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x1c\n\x14instance_description\x18\x04 \x01(\t\x12U\n\x06labels\x18\x05 \x03(\x0b\x32\x45.oak9.tython.gcp.compute_instance.ComputeInstanceTemplate.LabelsEntry\x12\x14\n\x0cmachine_type\x18\x06 \x01(\t\x12Y\n\x08metadata\x18\x07 \x03(\x0b\x32G.oak9.tython.gcp.compute_instance.ComputeInstanceTemplate.MetadataEntry\x12\x1c\n\x14metadata_fingerprint\x18\x08 \x01(\t\x12\x1f\n\x17metadata_startup_script\x18\t \x01(\t\x12\x18\n\x10min_cpu_platform\x18\n \x01(\t\x12\x0c\n\x04name\x18\x0b \x01(\t\x12\x13\n\x0bname_prefix\x18\x0c \x01(\t\x12\x0f\n\x07project\x18\r \x01(\t\x12\x0e\n\x06region\x18\x0e \x01(\t\x12\x11\n\tself_link\x18\x0f \x01(\t\x12\x0c\n\x04tags\x18\x10 \x03(\t\x12\x18\n\x10tags_fingerprint\x18\x11 \x01(\t\x12t\n\x19\x61\x64vanced_machine_features\x18\x12 \x01(\x0b\x32Q.oak9.tython.gcp.compute_instance.ComputeInstanceTemplateXAdvancedMachineFeatures\x12z\n\x1c\x63onfidential_instance_config\x18\x13 \x01(\x0b\x32T.oak9.tython.gcp.compute_instance.ComputeInstanceTemplateXConfidentialInstanceConfig\x12L\n\x04\x64isk\x18\x14 \x03(\x0b\x32>.oak9.tython.gcp.compute_instance.ComputeInstanceTemplateXDisk\x12\x65\n\x11guest_accelerator\x18\x15 \x03(\x0b\x32J.oak9.tython.gcp.compute_instance.ComputeInstanceTemplateXGuestAccelerator\x12\x65\n\x11network_interface\x18\x16 \x03(\x0b\x32J.oak9.tython.gcp.compute_instance.ComputeInstanceTemplateXNetworkInterface\x12k\n\x14reservation_affinity\x18\x17 \x01(\x0b\x32M.oak9.tython.gcp.compute_instance.ComputeInstanceTemplateXReservationAffinity\x12X\n\nscheduling\x18\x18 \x01(\x0b\x32\x44.oak9.tython.gcp.compute_instance.ComputeInstanceTemplateXScheduling\x12\x61\n\x0fservice_account\x18\x19 \x01(\x0b\x32H.oak9.tython.gcp.compute_instance.ComputeInstanceTemplateXServiceAccount\x12r\n\x18shielded_instance_config\x18\x1a \x01(\x0b\x32P.oak9.tython.gcp.compute_instance.ComputeInstanceTemplateXShieldedInstanceConfig\x12T\n\x08timeouts\x18\x1b \x01(\x0b\x32\x42.oak9.tython.gcp.compute_instance.ComputeInstanceTemplateXTimeouts\x12\x37\n\rresource_info\x18\x1c \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_compute_instance_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMPUTEINSTANCEXBOOTDISKXINITIALIZEPARAMS_LABELSENTRY._options = None
  _COMPUTEINSTANCEXBOOTDISKXINITIALIZEPARAMS_LABELSENTRY._serialized_options = b'8\001'
  _COMPUTEINSTANCE_GUESTACCELERATORENTRY._options = None
  _COMPUTEINSTANCE_GUESTACCELERATORENTRY._serialized_options = b'8\001'
  _COMPUTEINSTANCE_LABELSENTRY._options = None
  _COMPUTEINSTANCE_LABELSENTRY._serialized_options = b'8\001'
  _COMPUTEINSTANCE_METADATAENTRY._options = None
  _COMPUTEINSTANCE_METADATAENTRY._serialized_options = b'8\001'
  _COMPUTEINSTANCEFROMTEMPLATEXBOOTDISKXINITIALIZEPARAMS_LABELSENTRY._options = None
  _COMPUTEINSTANCEFROMTEMPLATEXBOOTDISKXINITIALIZEPARAMS_LABELSENTRY._serialized_options = b'8\001'
  _COMPUTEINSTANCEFROMTEMPLATEXNETWORKINTERFACE_ACCESSCONFIGENTRY._options = None
  _COMPUTEINSTANCEFROMTEMPLATEXNETWORKINTERFACE_ACCESSCONFIGENTRY._serialized_options = b'8\001'
  _COMPUTEINSTANCEFROMTEMPLATEXNETWORKINTERFACE_ALIASIPRANGEENTRY._options = None
  _COMPUTEINSTANCEFROMTEMPLATEXNETWORKINTERFACE_ALIASIPRANGEENTRY._serialized_options = b'8\001'
  _COMPUTEINSTANCEFROMTEMPLATE_ATTACHEDDISKENTRY._options = None
  _COMPUTEINSTANCEFROMTEMPLATE_ATTACHEDDISKENTRY._serialized_options = b'8\001'
  _COMPUTEINSTANCEFROMTEMPLATE_GUESTACCELERATORENTRY._options = None
  _COMPUTEINSTANCEFROMTEMPLATE_GUESTACCELERATORENTRY._serialized_options = b'8\001'
  _COMPUTEINSTANCEFROMTEMPLATE_LABELSENTRY._options = None
  _COMPUTEINSTANCEFROMTEMPLATE_LABELSENTRY._serialized_options = b'8\001'
  _COMPUTEINSTANCEFROMTEMPLATE_METADATAENTRY._options = None
  _COMPUTEINSTANCEFROMTEMPLATE_METADATAENTRY._serialized_options = b'8\001'
  _COMPUTEINSTANCEFROMTEMPLATE_SCRATCHDISKENTRY._options = None
  _COMPUTEINSTANCEFROMTEMPLATE_SCRATCHDISKENTRY._serialized_options = b'8\001'
  _COMPUTEINSTANCEFROMTEMPLATE_SERVICEACCOUNTENTRY._options = None
  _COMPUTEINSTANCEFROMTEMPLATE_SERVICEACCOUNTENTRY._serialized_options = b'8\001'
  _COMPUTEINSTANCEGROUPMANAGER_STATUSENTRY._options = None
  _COMPUTEINSTANCEGROUPMANAGER_STATUSENTRY._serialized_options = b'8\001'
  _COMPUTEINSTANCETEMPLATEXDISK_LABELSENTRY._options = None
  _COMPUTEINSTANCETEMPLATEXDISK_LABELSENTRY._serialized_options = b'8\001'
  _COMPUTEINSTANCETEMPLATE_LABELSENTRY._options = None
  _COMPUTEINSTANCETEMPLATE_LABELSENTRY._serialized_options = b'8\001'
  _COMPUTEINSTANCETEMPLATE_METADATAENTRY._options = None
  _COMPUTEINSTANCETEMPLATE_METADATAENTRY._serialized_options = b'8\001'
  _COMPUTEINSTANCEXADVANCEDMACHINEFEATURES._serialized_start=89
  _COMPUTEINSTANCEXADVANCEDMACHINEFEATURES._serialized_end=194
  _COMPUTEINSTANCEXATTACHEDDISK._serialized_start=197
  _COMPUTEINSTANCEXATTACHEDDISK._serialized_end=374
  _COMPUTEINSTANCEXBOOTDISKXINITIALIZEPARAMS._serialized_start=377
  _COMPUTEINSTANCEXBOOTDISKXINITIALIZEPARAMS._serialized_end=615
  _COMPUTEINSTANCEXBOOTDISKXINITIALIZEPARAMS_LABELSENTRY._serialized_start=570
  _COMPUTEINSTANCEXBOOTDISKXINITIALIZEPARAMS_LABELSENTRY._serialized_end=615
  _COMPUTEINSTANCEXBOOTDISK._serialized_start=618
  _COMPUTEINSTANCEXBOOTDISK._serialized_end=916
  _COMPUTEINSTANCEXCONFIDENTIALINSTANCECONFIG._serialized_start=918
  _COMPUTEINSTANCEXCONFIDENTIALINSTANCECONFIG._serialized_end=999
  _COMPUTEINSTANCEXNETWORKINTERFACEXACCESSCONFIG._serialized_start=1001
  _COMPUTEINSTANCEXNETWORKINTERFACEXACCESSCONFIG._serialized_end=1118
  _COMPUTEINSTANCEXNETWORKINTERFACEXALIASIPRANGE._serialized_start=1120
  _COMPUTEINSTANCEXNETWORKINTERFACEXALIASIPRANGE._serialized_end=1221
  _COMPUTEINSTANCEXNETWORKINTERFACEXIPV6ACCESSCONFIG._serialized_start=1224
  _COMPUTEINSTANCEXNETWORKINTERFACEXIPV6ACCESSCONFIG._serialized_end=1389
  _COMPUTEINSTANCEXNETWORKINTERFACE._serialized_start=1392
  _COMPUTEINSTANCEXNETWORKINTERFACE._serialized_end=1932
  _COMPUTEINSTANCEXRESERVATIONAFFINITYXSPECIFICRESERVATION._serialized_start=1934
  _COMPUTEINSTANCEXRESERVATIONAFFINITYXSPECIFICRESERVATION._serialized_end=2020
  _COMPUTEINSTANCEXRESERVATIONAFFINITY._serialized_start=2023
  _COMPUTEINSTANCEXRESERVATIONAFFINITY._serialized_end=2195
  _COMPUTEINSTANCEXSCHEDULINGXNODEAFFINITIES._serialized_start=2197
  _COMPUTEINSTANCEXSCHEDULINGXNODEAFFINITIES._serialized_end=2287
  _COMPUTEINSTANCEXSCHEDULING._serialized_start=2290
  _COMPUTEINSTANCEXSCHEDULING._serialized_end=2585
  _COMPUTEINSTANCEXSCRATCHDISK._serialized_start=2587
  _COMPUTEINSTANCEXSCRATCHDISK._serialized_end=2635
  _COMPUTEINSTANCEXSERVICEACCOUNT._serialized_start=2637
  _COMPUTEINSTANCEXSERVICEACCOUNT._serialized_end=2700
  _COMPUTEINSTANCEXSHIELDEDINSTANCECONFIG._serialized_start=2702
  _COMPUTEINSTANCEXSHIELDEDINSTANCECONFIG._serialized_end=2828
  _COMPUTEINSTANCEXTIMEOUTS._serialized_start=2830
  _COMPUTEINSTANCEXTIMEOUTS._serialized_end=2904
  _COMPUTEINSTANCE._serialized_start=2907
  _COMPUTEINSTANCE._serialized_end=4951
  _COMPUTEINSTANCE_GUESTACCELERATORENTRY._serialized_start=4800
  _COMPUTEINSTANCE_GUESTACCELERATORENTRY._serialized_end=4855
  _COMPUTEINSTANCE_LABELSENTRY._serialized_start=570
  _COMPUTEINSTANCE_LABELSENTRY._serialized_end=615
  _COMPUTEINSTANCE_METADATAENTRY._serialized_start=4904
  _COMPUTEINSTANCE_METADATAENTRY._serialized_end=4951
  _COMPUTEINSTANCEFROMTEMPLATEXADVANCEDMACHINEFEATURES._serialized_start=4953
  _COMPUTEINSTANCEFROMTEMPLATEXADVANCEDMACHINEFEATURES._serialized_end=5070
  _COMPUTEINSTANCEFROMTEMPLATEXBOOTDISKXINITIALIZEPARAMS._serialized_start=5073
  _COMPUTEINSTANCEFROMTEMPLATEXBOOTDISKXINITIALIZEPARAMS._serialized_end=5335
  _COMPUTEINSTANCEFROMTEMPLATEXBOOTDISKXINITIALIZEPARAMS_LABELSENTRY._serialized_start=570
  _COMPUTEINSTANCEFROMTEMPLATEXBOOTDISKXINITIALIZEPARAMS_LABELSENTRY._serialized_end=615
  _COMPUTEINSTANCEFROMTEMPLATEXBOOTDISK._serialized_start=5338
  _COMPUTEINSTANCEFROMTEMPLATEXBOOTDISK._serialized_end=5660
  _COMPUTEINSTANCEFROMTEMPLATEXCONFIDENTIALINSTANCECONFIG._serialized_start=5662
  _COMPUTEINSTANCEFROMTEMPLATEXCONFIDENTIALINSTANCECONFIG._serialized_end=5755
  _COMPUTEINSTANCEFROMTEMPLATEXNETWORKINTERFACEXIPV6ACCESSCONFIG._serialized_start=5758
  _COMPUTEINSTANCEFROMTEMPLATEXNETWORKINTERFACEXIPV6ACCESSCONFIG._serialized_end=5935
  _COMPUTEINSTANCEFROMTEMPLATEXNETWORKINTERFACE._serialized_start=5938
  _COMPUTEINSTANCEFROMTEMPLATEXNETWORKINTERFACE._serialized_end=6642
  _COMPUTEINSTANCEFROMTEMPLATEXNETWORKINTERFACE_ACCESSCONFIGENTRY._serialized_start=6538
  _COMPUTEINSTANCEFROMTEMPLATEXNETWORKINTERFACE_ACCESSCONFIGENTRY._serialized_end=6589
  _COMPUTEINSTANCEFROMTEMPLATEXNETWORKINTERFACE_ALIASIPRANGEENTRY._serialized_start=6591
  _COMPUTEINSTANCEFROMTEMPLATEXNETWORKINTERFACE_ALIASIPRANGEENTRY._serialized_end=6642
  _COMPUTEINSTANCEFROMTEMPLATEXRESERVATIONAFFINITYXSPECIFICRESERVATION._serialized_start=6644
  _COMPUTEINSTANCEFROMTEMPLATEXRESERVATIONAFFINITYXSPECIFICRESERVATION._serialized_end=6742
  _COMPUTEINSTANCEFROMTEMPLATEXRESERVATIONAFFINITY._serialized_start=6745
  _COMPUTEINSTANCEFROMTEMPLATEXRESERVATIONAFFINITY._serialized_end=6942
  _COMPUTEINSTANCEFROMTEMPLATEXSCHEDULINGXNODEAFFINITIES._serialized_start=6944
  _COMPUTEINSTANCEFROMTEMPLATEXSCHEDULINGXNODEAFFINITIES._serialized_end=7046
  _COMPUTEINSTANCEFROMTEMPLATEXSCHEDULING._serialized_start=7049
  _COMPUTEINSTANCEFROMTEMPLATEXSCHEDULING._serialized_end=7368
  _COMPUTEINSTANCEFROMTEMPLATEXSHIELDEDINSTANCECONFIG._serialized_start=7371
  _COMPUTEINSTANCEFROMTEMPLATEXSHIELDEDINSTANCECONFIG._serialized_end=7509
  _COMPUTEINSTANCEFROMTEMPLATEXTIMEOUTS._serialized_start=7511
  _COMPUTEINSTANCEFROMTEMPLATEXTIMEOUTS._serialized_end=7597
  _COMPUTEINSTANCEFROMTEMPLATE._serialized_start=7600
  _COMPUTEINSTANCEFROMTEMPLATE._serialized_end=10033
  _COMPUTEINSTANCEFROMTEMPLATE_ATTACHEDDISKENTRY._serialized_start=9722
  _COMPUTEINSTANCEFROMTEMPLATE_ATTACHEDDISKENTRY._serialized_end=9773
  _COMPUTEINSTANCEFROMTEMPLATE_GUESTACCELERATORENTRY._serialized_start=4800
  _COMPUTEINSTANCEFROMTEMPLATE_GUESTACCELERATORENTRY._serialized_end=4855
  _COMPUTEINSTANCEFROMTEMPLATE_LABELSENTRY._serialized_start=570
  _COMPUTEINSTANCEFROMTEMPLATE_LABELSENTRY._serialized_end=615
  _COMPUTEINSTANCEFROMTEMPLATE_METADATAENTRY._serialized_start=4904
  _COMPUTEINSTANCEFROMTEMPLATE_METADATAENTRY._serialized_end=4951
  _COMPUTEINSTANCEFROMTEMPLATE_SCRATCHDISKENTRY._serialized_start=9928
  _COMPUTEINSTANCEFROMTEMPLATE_SCRATCHDISKENTRY._serialized_end=9978
  _COMPUTEINSTANCEFROMTEMPLATE_SERVICEACCOUNTENTRY._serialized_start=9980
  _COMPUTEINSTANCEFROMTEMPLATE_SERVICEACCOUNTENTRY._serialized_end=10033
  _COMPUTEINSTANCEGROUPXNAMEDPORT._serialized_start=10035
  _COMPUTEINSTANCEGROUPXNAMEDPORT._serialized_end=10095
  _COMPUTEINSTANCEGROUPXTIMEOUTS._serialized_start=10097
  _COMPUTEINSTANCEGROUPXTIMEOUTS._serialized_end=10176
  _COMPUTEINSTANCEGROUP._serialized_start=10179
  _COMPUTEINSTANCEGROUP._serialized_end=10574
  _COMPUTEINSTANCEGROUPMANAGERXAUTOHEALINGPOLICIES._serialized_start=10576
  _COMPUTEINSTANCEGROUPMANAGERXAUTOHEALINGPOLICIES._serialized_end=10674
  _COMPUTEINSTANCEGROUPMANAGERXNAMEDPORT._serialized_start=10676
  _COMPUTEINSTANCEGROUPMANAGERXNAMEDPORT._serialized_end=10743
  _COMPUTEINSTANCEGROUPMANAGERXSTATEFULDISK._serialized_start=10745
  _COMPUTEINSTANCEGROUPMANAGERXSTATEFULDISK._serialized_end=10829
  _COMPUTEINSTANCEGROUPMANAGERXTIMEOUTS._serialized_start=10831
  _COMPUTEINSTANCEGROUPMANAGERXTIMEOUTS._serialized_end=10917
  _COMPUTEINSTANCEGROUPMANAGERXUPDATEPOLICY._serialized_start=10920
  _COMPUTEINSTANCEGROUPMANAGERXUPDATEPOLICY._serialized_end=11184
  _COMPUTEINSTANCEGROUPMANAGERXVERSIONXTARGETSIZE._serialized_start=11186
  _COMPUTEINSTANCEGROUPMANAGERXVERSIONXTARGETSIZE._serialized_end=11266
  _COMPUTEINSTANCEGROUPMANAGERXVERSION._serialized_start=11269
  _COMPUTEINSTANCEGROUPMANAGERXVERSION._serialized_end=11450
  _COMPUTEINSTANCEGROUPMANAGER._serialized_start=11453
  _COMPUTEINSTANCEGROUPMANAGER._serialized_end=12555
  _COMPUTEINSTANCEGROUPMANAGER_STATUSENTRY._serialized_start=12510
  _COMPUTEINSTANCEGROUPMANAGER_STATUSENTRY._serialized_end=12555
  _COMPUTEINSTANCEGROUPNAMEDPORTXTIMEOUTS._serialized_start=12557
  _COMPUTEINSTANCEGROUPNAMEDPORTXTIMEOUTS._serialized_end=12629
  _COMPUTEINSTANCEGROUPNAMEDPORT._serialized_start=12632
  _COMPUTEINSTANCEGROUPNAMEDPORT._serialized_end=12898
  _COMPUTEINSTANCEIAMBINDINGXCONDITION._serialized_start=12900
  _COMPUTEINSTANCEIAMBINDINGXCONDITION._serialized_end=12993
  _COMPUTEINSTANCEIAMBINDING._serialized_start=12996
  _COMPUTEINSTANCEIAMBINDING._serialized_end=13281
  _COMPUTEINSTANCEIAMMEMBERXCONDITION._serialized_start=13283
  _COMPUTEINSTANCEIAMMEMBERXCONDITION._serialized_end=13375
  _COMPUTEINSTANCEIAMMEMBER._serialized_start=13378
  _COMPUTEINSTANCEIAMMEMBER._serialized_end=13660
  _COMPUTEINSTANCEIAMPOLICY._serialized_start=13663
  _COMPUTEINSTANCEIAMPOLICY._serialized_end=13847
  _COMPUTEINSTANCETEMPLATEXADVANCEDMACHINEFEATURES._serialized_start=13849
  _COMPUTEINSTANCETEMPLATEXADVANCEDMACHINEFEATURES._serialized_end=13962
  _COMPUTEINSTANCETEMPLATEXCONFIDENTIALINSTANCECONFIG._serialized_start=13964
  _COMPUTEINSTANCETEMPLATEXCONFIDENTIALINSTANCECONFIG._serialized_end=14053
  _COMPUTEINSTANCETEMPLATEXDISKXDISKENCRYPTIONKEY._serialized_start=14055
  _COMPUTEINSTANCETEMPLATEXDISKXDISKENCRYPTIONKEY._serialized_end=14130
  _COMPUTEINSTANCETEMPLATEXDISK._serialized_start=14133
  _COMPUTEINSTANCETEMPLATEXDISK._serialized_end=14641
  _COMPUTEINSTANCETEMPLATEXDISK_LABELSENTRY._serialized_start=570
  _COMPUTEINSTANCETEMPLATEXDISK_LABELSENTRY._serialized_end=615
  _COMPUTEINSTANCETEMPLATEXGUESTACCELERATOR._serialized_start=14643
  _COMPUTEINSTANCETEMPLATEXGUESTACCELERATOR._serialized_end=14714
  _COMPUTEINSTANCETEMPLATEXNETWORKINTERFACEXACCESSCONFIG._serialized_start=14716
  _COMPUTEINSTANCETEMPLATEXNETWORKINTERFACEXACCESSCONFIG._serialized_end=14841
  _COMPUTEINSTANCETEMPLATEXNETWORKINTERFACEXALIASIPRANGE._serialized_start=14843
  _COMPUTEINSTANCETEMPLATEXNETWORKINTERFACEXALIASIPRANGE._serialized_end=14952
  _COMPUTEINSTANCETEMPLATEXNETWORKINTERFACEXIPV6ACCESSCONFIG._serialized_start=14955
  _COMPUTEINSTANCETEMPLATEXNETWORKINTERFACEXIPV6ACCESSCONFIG._serialized_end=15128
  _COMPUTEINSTANCETEMPLATEXNETWORKINTERFACE._serialized_start=15131
  _COMPUTEINSTANCETEMPLATEXNETWORKINTERFACE._serialized_end=15703
  _COMPUTEINSTANCETEMPLATEXRESERVATIONAFFINITYXSPECIFICRESERVATION._serialized_start=15705
  _COMPUTEINSTANCETEMPLATEXRESERVATIONAFFINITYXSPECIFICRESERVATION._serialized_end=15799
  _COMPUTEINSTANCETEMPLATEXRESERVATIONAFFINITY._serialized_start=15802
  _COMPUTEINSTANCETEMPLATEXRESERVATIONAFFINITY._serialized_end=15990
  _COMPUTEINSTANCETEMPLATEXSCHEDULINGXNODEAFFINITIES._serialized_start=15992
  _COMPUTEINSTANCETEMPLATEXSCHEDULINGXNODEAFFINITIES._serialized_end=16090
  _COMPUTEINSTANCETEMPLATEXSCHEDULING._serialized_start=16093
  _COMPUTEINSTANCETEMPLATEXSCHEDULING._serialized_end=16404
  _COMPUTEINSTANCETEMPLATEXSERVICEACCOUNT._serialized_start=16406
  _COMPUTEINSTANCETEMPLATEXSERVICEACCOUNT._serialized_end=16477
  _COMPUTEINSTANCETEMPLATEXSHIELDEDINSTANCECONFIG._serialized_start=16480
  _COMPUTEINSTANCETEMPLATEXSHIELDEDINSTANCECONFIG._serialized_end=16614
  _COMPUTEINSTANCETEMPLATEXTIMEOUTS._serialized_start=16616
  _COMPUTEINSTANCETEMPLATEXTIMEOUTS._serialized_end=16682
  _COMPUTEINSTANCETEMPLATE._serialized_start=16685
  _COMPUTEINSTANCETEMPLATE._serialized_end=18392
  _COMPUTEINSTANCETEMPLATE_LABELSENTRY._serialized_start=570
  _COMPUTEINSTANCETEMPLATE_LABELSENTRY._serialized_end=615
  _COMPUTEINSTANCETEMPLATE_METADATAENTRY._serialized_start=4904
  _COMPUTEINSTANCETEMPLATE_METADATAENTRY._serialized_end=4951
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class StorageBucketXCors(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAX_AGE_SECONDS_FIELD_NUMBER: builtins.int
    METHOD_FIELD_NUMBER: builtins.int
    ORIGIN_FIELD_NUMBER: builtins.int
    RESPONSE_HEADER_FIELD_NUMBER: builtins.int
    max_age_seconds: builtins.float
    @property
    def method(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def origin(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def response_header(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        max_age_seconds: builtins.float = ...,
        method: collections.abc.Iterable[builtins.str] | None = ...,
        origin: collections.abc.Iterable[builtins.str] | None = ...,
        response_header: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["max_age_seconds", b"max_age_seconds", "method", b"method", "origin", b"origin", "response_header", b"response_header"]) -> None: ...

global___StorageBucketXCors = StorageBucketXCors

@typing_extensions.final
class StorageBucketXEncryption(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEFAULT_KMS_KEY_NAME_FIELD_NUMBER: builtins.int
    default_kms_key_name: builtins.str
    def __init__(
        self,
        *,
        default_kms_key_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["default_kms_key_name", b"default_kms_key_name"]) -> None: ...

global___StorageBucketXEncryption = StorageBucketXEncryption

@typing_extensions.final
class StorageBucketXLifecycleRuleXAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STORAGE_CLASS_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    storage_class: builtins.str
    type: builtins.str
    def __init__(
        self,
        *,
        storage_class: builtins.str = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["storage_class", b"storage_class", "type", b"type"]) -> None: ...

global___StorageBucketXLifecycleRuleXAction = StorageBucketXLifecycleRuleXAction

@typing_extensions.final
class StorageBucketXLifecycleRuleXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AGE_FIELD_NUMBER: builtins.int
    CREATED_BEFORE_FIELD_NUMBER: builtins.int
    CUSTOM_TIME_BEFORE_FIELD_NUMBER: builtins.int
    DAYS_SINCE_CUSTOM_TIME_FIELD_NUMBER: builtins.int
    DAYS_SINCE_NONCURRENT_TIME_FIELD_NUMBER: builtins.int
    MATCHES_PREFIX_FIELD_NUMBER: builtins.int
    MATCHES_STORAGE_CLASS_FIELD_NUMBER: builtins.int
    MATCHES_SUFFIX_FIELD_NUMBER: builtins.int
    NONCURRENT_TIME_BEFORE_FIELD_NUMBER: builtins.int
    NUM_NEWER_VERSIONS_FIELD_NUMBER: builtins.int
    WITH_STATE_FIELD_NUMBER: builtins.int
    age: builtins.float
    created_before: builtins.str
    custom_time_before: builtins.str
    days_since_custom_time: builtins.float
    days_since_noncurrent_time: builtins.float
    @property
    def matches_prefix(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def matches_storage_class(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def matches_suffix(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    noncurrent_time_before: builtins.str
    num_newer_versions: builtins.float
    with_state: builtins.str
    def __init__(
        self,
        *,
        age: builtins.float = ...,
        created_before: builtins.str = ...,
        custom_time_before: builtins.str = ...,
        days_since_custom_time: builtins.float = ...,
        days_since_noncurrent_time: builtins.float = ...,
        matches_prefix: collections.abc.Iterable[builtins.str] | None = ...,
        matches_storage_class: collections.abc.Iterable[builtins.str] | None = ...,
        matches_suffix: collections.abc.Iterable[builtins.str] | None = ...,
        noncurrent_time_before: builtins.str = ...,
        num_newer_versions: builtins.float = ...,
        with_state: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["age", b"age", "created_before", b"created_before", "custom_time_before", b"custom_time_before", "days_since_custom_time", b"days_since_custom_time", "days_since_noncurrent_time", b"days_since_noncurrent_time", "matches_prefix", b"matches_prefix", "matches_storage_class", b"matches_storage_class", "matches_suffix", b"matches_suffix", "noncurrent_time_before", b"noncurrent_time_before", "num_newer_versions", b"num_newer_versions", "with_state", b"with_state"]) -> None: ...

global___StorageBucketXLifecycleRuleXCondition = StorageBucketXLifecycleRuleXCondition

@typing_extensions.final
class StorageBucketXLifecycleRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTION_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    @property
    def action(self) -> global___StorageBucketXLifecycleRuleXAction: ...
    @property
    def condition(self) -> global___StorageBucketXLifecycleRuleXCondition: ...
    def __init__(
        self,
        *,
        action: global___StorageBucketXLifecycleRuleXAction | None = ...,
        condition: global___StorageBucketXLifecycleRuleXCondition | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["action", b"action", "condition", b"condition"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["action", b"action", "condition", b"condition"]) -> None: ...

global___StorageBucketXLifecycleRule = StorageBucketXLifecycleRule

@typing_extensions.final
class StorageBucketXLogging(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOG_BUCKET_FIELD_NUMBER: builtins.int
    LOG_OBJECT_PREFIX_FIELD_NUMBER: builtins.int
    log_bucket: builtins.str
    log_object_prefix: builtins.str
    def __init__(
        self,
        *,
        log_bucket: builtins.str = ...,
        log_object_prefix: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["log_bucket", b"log_bucket", "log_object_prefix", b"log_object_prefix"]) -> None: ...

global___StorageBucketXLogging = StorageBucketXLogging

@typing_extensions.final
class StorageBucketXRetentionPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IS_LOCKED_FIELD_NUMBER: builtins.int
    RETENTION_PERIOD_FIELD_NUMBER: builtins.int
    is_locked: builtins.bool
    retention_period: builtins.float
    def __init__(
        self,
        *,
        is_locked: builtins.bool = ...,
        retention_period: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["is_locked", b"is_locked", "retention_period", b"retention_period"]) -> None: ...

global___StorageBucketXRetentionPolicy = StorageBucketXRetentionPolicy

@typing_extensions.final
class StorageBucketXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    READ_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    read: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        read: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "read", b"read", "update", b"update"]) -> None: ...

global___StorageBucketXTimeouts = StorageBucketXTimeouts

@typing_extensions.final
class StorageBucketXVersioning(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLED_FIELD_NUMBER: builtins.int
    enabled: builtins.bool
    def __init__(
        self,
        *,
        enabled: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["enabled", b"enabled"]) -> None: ...

global___StorageBucketXVersioning = StorageBucketXVersioning

@typing_extensions.final
class StorageBucketXWebsite(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAIN_PAGE_SUFFIX_FIELD_NUMBER: builtins.int
    NOT_FOUND_PAGE_FIELD_NUMBER: builtins.int
    main_page_suffix: builtins.str
    not_found_page: builtins.str
    def __init__(
        self,
        *,
        main_page_suffix: builtins.str = ...,
        not_found_page: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["main_page_suffix", b"main_page_suffix", "not_found_page", b"not_found_page"]) -> None: ...

global___StorageBucketXWebsite = StorageBucketXWebsite

@typing_extensions.final
class StorageBucket(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    DEFAULT_EVENT_BASED_HOLD_FIELD_NUMBER: builtins.int
    FORCE_DESTROY_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REQUESTER_PAYS_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    STORAGE_CLASS_FIELD_NUMBER: builtins.int
    UNIFORM_BUCKET_LEVEL_ACCESS_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    CORS_FIELD_NUMBER: builtins.int
    ENCRYPTION_FIELD_NUMBER: builtins.int
    LIFECYCLE_RULE_FIELD_NUMBER: builtins.int
    LOGGING_FIELD_NUMBER: builtins.int
    RETENTION_POLICY_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    VERSIONING_FIELD_NUMBER: builtins.int
    WEBSITE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    default_event_based_hold: builtins.bool
    force_destroy: builtins.bool
    id: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    location: builtins.str
    name: builtins.str
    project: builtins.str
    requester_pays: builtins.bool
    self_link: builtins.str
    storage_class: builtins.str
    uniform_bucket_level_access: builtins.bool
    url: builtins.str
    @property
    def cors(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___StorageBucketXCors]: ...
    @property
    def encryption(self) -> global___StorageBucketXEncryption: ...
    @property
    def lifecycle_rule(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___StorageBucketXLifecycleRule]: ...
    @property
    def logging(self) -> global___StorageBucketXLogging: ...
    @property
    def retention_policy(self) -> global___StorageBucketXRetentionPolicy: ...
    @property
    def timeouts(self) -> global___StorageBucketXTimeouts: ...
    @property
    def versioning(self) -> global___StorageBucketXVersioning: ...
    @property
    def website(self) -> global___StorageBucketXWebsite: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        default_event_based_hold: builtins.bool = ...,
        force_destroy: builtins.bool = ...,
        id: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        requester_pays: builtins.bool = ...,
        self_link: builtins.str = ...,
        storage_class: builtins.str = ...,
        uniform_bucket_level_access: builtins.bool = ...,
        url: builtins.str = ...,
        cors: collections.abc.Iterable[global___StorageBucketXCors] | None = ...,
        encryption: global___StorageBucketXEncryption | None = ...,
        lifecycle_rule: collections.abc.Iterable[global___StorageBucketXLifecycleRule] | None = ...,
        logging: global___StorageBucketXLogging | None = ...,
        retention_policy: global___StorageBucketXRetentionPolicy | None = ...,
        timeouts: global___StorageBucketXTimeouts | None = ...,
        versioning: global___StorageBucketXVersioning | None = ...,
        website: global___StorageBucketXWebsite | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["encryption", b"encryption", "logging", b"logging", "resource_info", b"resource_info", "retention_policy", b"retention_policy", "timeouts", b"timeouts", "versioning", b"versioning", "website", b"website"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cors", b"cors", "default_event_based_hold", b"default_event_based_hold", "encryption", b"encryption", "force_destroy", b"force_destroy", "id", b"id", "labels", b"labels", "lifecycle_rule", b"lifecycle_rule", "location", b"location", "logging", b"logging", "name", b"name", "project", b"project", "requester_pays", b"requester_pays", "resource_info", b"resource_info", "retention_policy", b"retention_policy", "self_link", b"self_link", "storage_class", b"storage_class", "timeouts", b"timeouts", "uniform_bucket_level_access", b"uniform_bucket_level_access", "url", b"url", "versioning", b"versioning", "website", b"website"]) -> None: ...

global___StorageBucket = StorageBucket

@typing_extensions.final
class StorageBucketAccessControlXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___StorageBucketAccessControlXTimeouts = StorageBucketAccessControlXTimeouts

@typing_extensions.final
class StorageBucketAccessControl(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUCKET_FIELD_NUMBER: builtins.int
    DOMAIN_FIELD_NUMBER: builtins.int
    EMAIL_FIELD_NUMBER: builtins.int
    ENTITY_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    bucket: builtins.str
    domain: builtins.str
    email: builtins.str
    entity: builtins.str
    id: builtins.str
    role: builtins.str
    @property
    def timeouts(self) -> global___StorageBucketAccessControlXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        bucket: builtins.str = ...,
        domain: builtins.str = ...,
        email: builtins.str = ...,
        entity: builtins.str = ...,
        id: builtins.str = ...,
        role: builtins.str = ...,
        timeouts: global___StorageBucketAccessControlXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bucket", b"bucket", "domain", b"domain", "email", b"email", "entity", b"entity", "id", b"id", "resource_info", b"resource_info", "role", b"role", "timeouts", b"timeouts"]) -> None: ...

global___StorageBucketAccessControl = StorageBucketAccessControl

@typing_extensions.final
class StorageBucketAcl(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUCKET_FIELD_NUMBER: builtins.int
    DEFAULT_ACL_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    PREDEFINED_ACL_FIELD_NUMBER: builtins.int
    ROLE_ENTITY_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    bucket: builtins.str
    default_acl: builtins.str
    id: builtins.str
    predefined_acl: builtins.str
    @property
    def role_entity(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        bucket: builtins.str = ...,
        default_acl: builtins.str = ...,
        id: builtins.str = ...,
        predefined_acl: builtins.str = ...,
        role_entity: collections.abc.Iterable[builtins.str] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bucket", b"bucket", "default_acl", b"default_acl", "id", b"id", "predefined_acl", b"predefined_acl", "resource_info", b"resource_info", "role_entity", b"role_entity"]) -> None: ...

global___StorageBucketAcl = StorageBucketAcl

@typing_extensions.final
class StorageBucketIamBindingXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___StorageBucketIamBindingXCondition = StorageBucketIamBindingXCondition

@typing_extensions.final
class StorageBucketIamBinding(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUCKET_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MEMBERS_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    bucket: builtins.str
    etag: builtins.str
    id: builtins.str
    @property
    def members(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    role: builtins.str
    @property
    def condition(self) -> global___StorageBucketIamBindingXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        bucket: builtins.str = ...,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        members: collections.abc.Iterable[builtins.str] | None = ...,
        role: builtins.str = ...,
        condition: global___StorageBucketIamBindingXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bucket", b"bucket", "condition", b"condition", "etag", b"etag", "id", b"id", "members", b"members", "resource_info", b"resource_info", "role", b"role"]) -> None: ...

global___StorageBucketIamBinding = StorageBucketIamBinding

@typing_extensions.final
class StorageBucketIamMemberXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___StorageBucketIamMemberXCondition = StorageBucketIamMemberXCondition

@typing_extensions.final
class StorageBucketIamMember(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUCKET_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MEMBER_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    bucket: builtins.str
    etag: builtins.str
    id: builtins.str
    member: builtins.str
    role: builtins.str
    @property
    def condition(self) -> global___StorageBucketIamMemberXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        bucket: builtins.str = ...,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        member: builtins.str = ...,
        role: builtins.str = ...,
        condition: global___StorageBucketIamMemberXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bucket", b"bucket", "condition", b"condition", "etag", b"etag", "id", b"id", "member", b"member", "resource_info", b"resource_info", "role", b"role"]) -> None: ...

global___StorageBucketIamMember = StorageBucketIamMember

@typing_extensions.final
class StorageBucketIamPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUCKET_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    POLICY_DATA_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    bucket: builtins.str
    etag: builtins.str
    id: builtins.str
    policy_data: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        bucket: builtins.str = ...,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        policy_data: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bucket", b"bucket", "etag", b"etag", "id", b"id", "policy_data", b"policy_data", "resource_info", b"resource_info"]) -> None: ...

global___StorageBucketIamPolicy = StorageBucketIamPolicy

@typing_extensions.final
class StorageBucketObjectXCustomerEncryption(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENCRYPTION_ALGORITHM_FIELD_NUMBER: builtins.int
    ENCRYPTION_KEY_FIELD_NUMBER: builtins.int
    encryption_algorithm: builtins.str
    encryption_key: builtins.str
    def __init__(
        self,
        *,
        encryption_algorithm: builtins.str = ...,
        encryption_key: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["encryption_algorithm", b"encryption_algorithm", "encryption_key", b"encryption_key"]) -> None: ...

global___StorageBucketObjectXCustomerEncryption = StorageBucketObjectXCustomerEncryption

@typing_extensions.final
class StorageBucketObjectXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___StorageBucketObjectXTimeouts = StorageBucketObjectXTimeouts

@typing_extensions.final
class StorageBucketObject(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class MetadataEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    BUCKET_FIELD_NUMBER: builtins.int
    CACHE_CONTROL_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    CONTENT_DISPOSITION_FIELD_NUMBER: builtins.int
    CONTENT_ENCODING_FIELD_NUMBER: builtins.int
    CONTENT_LANGUAGE_FIELD_NUMBER: builtins.int
    CONTENT_TYPE_FIELD_NUMBER: builtins.int
    CRC32C_FIELD_NUMBER: builtins.int
    DETECT_MD5HASH_FIELD_NUMBER: builtins.int
    EVENT_BASED_HOLD_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    KMS_KEY_NAME_FIELD_NUMBER: builtins.int
    MD5HASH_FIELD_NUMBER: builtins.int
    MEDIA_LINK_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    OUTPUT_NAME_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    STORAGE_CLASS_FIELD_NUMBER: builtins.int
    TEMPORARY_HOLD_FIELD_NUMBER: builtins.int
    CUSTOMER_ENCRYPTION_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    bucket: builtins.str
    cache_control: builtins.str
    content: builtins.str
    content_disposition: builtins.str
    content_encoding: builtins.str
    content_language: builtins.str
    content_type: builtins.str
    crc32c: builtins.str
    detect_md5hash: builtins.str
    event_based_hold: builtins.bool
    id: builtins.str
    kms_key_name: builtins.str
    md5hash: builtins.str
    media_link: builtins.str
    @property
    def metadata(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    name: builtins.str
    output_name: builtins.str
    self_link: builtins.str
    source: builtins.str
    storage_class: builtins.str
    temporary_hold: builtins.bool
    @property
    def customer_encryption(self) -> global___StorageBucketObjectXCustomerEncryption: ...
    @property
    def timeouts(self) -> global___StorageBucketObjectXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        bucket: builtins.str = ...,
        cache_control: builtins.str = ...,
        content: builtins.str = ...,
        content_disposition: builtins.str = ...,
        content_encoding: builtins.str = ...,
        content_language: builtins.str = ...,
        content_type: builtins.str = ...,
        crc32c: builtins.str = ...,
        detect_md5hash: builtins.str = ...,
        event_based_hold: builtins.bool = ...,
        id: builtins.str = ...,
        kms_key_name: builtins.str = ...,
        md5hash: builtins.str = ...,
        media_link: builtins.str = ...,
        metadata: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        name: builtins.str = ...,
        output_name: builtins.str = ...,
        self_link: builtins.str = ...,
        source: builtins.str = ...,
        storage_class: builtins.str = ...,
        temporary_hold: builtins.bool = ...,
        customer_encryption: global___StorageBucketObjectXCustomerEncryption | None = ...,
        timeouts: global___StorageBucketObjectXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["customer_encryption", b"customer_encryption", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bucket", b"bucket", "cache_control", b"cache_control", "content", b"content", "content_disposition", b"content_disposition", "content_encoding", b"content_encoding", "content_language", b"content_language", "content_type", b"content_type", "crc32c", b"crc32c", "customer_encryption", b"customer_encryption", "detect_md5hash", b"detect_md5hash", "event_based_hold", b"event_based_hold", "id", b"id", "kms_key_name", b"kms_key_name", "md5hash", b"md5hash", "media_link", b"media_link", "metadata", b"metadata", "name", b"name", "output_name", b"output_name", "resource_info", b"resource_info", "self_link", b"self_link", "source", b"source", "storage_class", b"storage_class", "temporary_hold", b"temporary_hold", "timeouts", b"timeouts"]) -> None: ...

global___StorageBucketObject = StorageBucketObject

@typing_extensions.final
class StorageDefaultObjectAccessControlXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___StorageDefaultObjectAccessControlXTimeouts = StorageDefaultObjectAccessControlXTimeouts

@typing_extensions.final
class StorageDefaultObjectAccessControl(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class ProjectTeamEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    BUCKET_FIELD_NUMBER: builtins.int
    DOMAIN_FIELD_NUMBER: builtins.int
    EMAIL_FIELD_NUMBER: builtins.int
    ENTITY_FIELD_NUMBER: builtins.int
    ENTITY_ID_FIELD_NUMBER: builtins.int
    GENERATION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    OBJECT_FIELD_NUMBER: builtins.int
    PROJECT_TEAM_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    bucket: builtins.str
    domain: builtins.str
    email: builtins.str
    entity: builtins.str
    entity_id: builtins.str
    generation: builtins.float
    id: builtins.str
    object: builtins.str
    @property
    def project_team(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    role: builtins.str
    @property
    def timeouts(self) -> global___StorageDefaultObjectAccessControlXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        bucket: builtins.str = ...,
        domain: builtins.str = ...,
        email: builtins.str = ...,
        entity: builtins.str = ...,
        entity_id: builtins.str = ...,
        generation: builtins.float = ...,
        id: builtins.str = ...,
        object: builtins.str = ...,
        project_team: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        role: builtins.str = ...,
        timeouts: global___StorageDefaultObjectAccessControlXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bucket", b"bucket", "domain", b"domain", "email", b"email", "entity", b"entity", "entity_id", b"entity_id", "generation", b"generation", "id", b"id", "object", b"object", "project_team", b"project_team", "resource_info", b"resource_info", "role", b"role", "timeouts", b"timeouts"]) -> None: ...

global___StorageDefaultObjectAccessControl = StorageDefaultObjectAccessControl

@typing_extensions.final
class StorageDefaultObjectAcl(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUCKET_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    ROLE_ENTITY_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    bucket: builtins.str
    id: builtins.str
    @property
    def role_entity(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        bucket: builtins.str = ...,
        id: builtins.str = ...,
        role_entity: collections.abc.Iterable[builtins.str] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bucket", b"bucket", "id", b"id", "resource_info", b"resource_info", "role_entity", b"role_entity"]) -> None: ...

global___StorageDefaultObjectAcl = StorageDefaultObjectAcl

@typing_extensions.final
class StorageHmacKeyXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___StorageHmacKeyXTimeouts = StorageHmacKeyXTimeouts

@typing_extensions.final
class StorageHmacKey(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCESS_ID_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    SECRET_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_EMAIL_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    TIME_CREATED_FIELD_NUMBER: builtins.int
    UPDATED_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    access_id: builtins.str
    id: builtins.str
    project: builtins.str
    secret: builtins.str
    service_account_email: builtins.str
    state: builtins.str
    time_created: builtins.str
    updated: builtins.str
    @property
    def timeouts(self) -> global___StorageHmacKeyXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        access_id: builtins.str = ...,
        id: builtins.str = ...,
        project: builtins.str = ...,
        secret: builtins.str = ...,
        service_account_email: builtins.str = ...,
        state: builtins.str = ...,
        time_created: builtins.str = ...,
        updated: builtins.str = ...,
        timeouts: global___StorageHmacKeyXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["access_id", b"access_id", "id", b"id", "project", b"project", "resource_info", b"resource_info", "secret", b"secret", "service_account_email", b"service_account_email", "state", b"state", "time_created", b"time_created", "timeouts", b"timeouts", "updated", b"updated"]) -> None: ...

global___StorageHmacKey = StorageHmacKey

@typing_extensions.final
class StorageNotification(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class CustomAttributesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    BUCKET_FIELD_NUMBER: builtins.int
    CUSTOM_ATTRIBUTES_FIELD_NUMBER: builtins.int
    EVENT_TYPES_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NOTIFICATION_ID_FIELD_NUMBER: builtins.int
    OBJECT_NAME_PREFIX_FIELD_NUMBER: builtins.int
    PAYLOAD_FORMAT_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    TOPIC_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    bucket: builtins.str
    @property
    def custom_attributes(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def event_types(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    id: builtins.str
    notification_id: builtins.str
    object_name_prefix: builtins.str
    payload_format: builtins.str
    self_link: builtins.str
    topic: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        bucket: builtins.str = ...,
        custom_attributes: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        event_types: collections.abc.Iterable[builtins.str] | None = ...,
        id: builtins.str = ...,
        notification_id: builtins.str = ...,
        object_name_prefix: builtins.str = ...,
        payload_format: builtins.str = ...,
        self_link: builtins.str = ...,
        topic: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bucket", b"bucket", "custom_attributes", b"custom_attributes", "event_types", b"event_types", "id", b"id", "notification_id", b"notification_id", "object_name_prefix", b"object_name_prefix", "payload_format", b"payload_format", "resource_info", b"resource_info", "self_link", b"self_link", "topic", b"topic"]) -> None: ...

global___StorageNotification = StorageNotification

@typing_extensions.final
class StorageObjectAccessControlXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___StorageObjectAccessControlXTimeouts = StorageObjectAccessControlXTimeouts

@typing_extensions.final
class StorageObjectAccessControl(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class ProjectTeamEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    BUCKET_FIELD_NUMBER: builtins.int
    DOMAIN_FIELD_NUMBER: builtins.int
    EMAIL_FIELD_NUMBER: builtins.int
    ENTITY_FIELD_NUMBER: builtins.int
    ENTITY_ID_FIELD_NUMBER: builtins.int
    GENERATION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    OBJECT_FIELD_NUMBER: builtins.int
    PROJECT_TEAM_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    bucket: builtins.str
    domain: builtins.str
    email: builtins.str
    entity: builtins.str
    entity_id: builtins.str
    generation: builtins.float
    id: builtins.str
    object: builtins.str
    @property
    def project_team(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    role: builtins.str
    @property
    def timeouts(self) -> global___StorageObjectAccessControlXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        bucket: builtins.str = ...,
        domain: builtins.str = ...,
        email: builtins.str = ...,
        entity: builtins.str = ...,
        entity_id: builtins.str = ...,
        generation: builtins.float = ...,
        id: builtins.str = ...,
        object: builtins.str = ...,
        project_team: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        role: builtins.str = ...,
        timeouts: global___StorageObjectAccessControlXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bucket", b"bucket", "domain", b"domain", "email", b"email", "entity", b"entity", "entity_id", b"entity_id", "generation", b"generation", "id", b"id", "object", b"object", "project_team", b"project_team", "resource_info", b"resource_info", "role", b"role", "timeouts", b"timeouts"]) -> None: ...

global___StorageObjectAccessControl = StorageObjectAccessControl

@typing_extensions.final
class StorageObjectAcl(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUCKET_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    OBJECT_FIELD_NUMBER: builtins.int
    PREDEFINED_ACL_FIELD_NUMBER: builtins.int
    ROLE_ENTITY_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    bucket: builtins.str
    id: builtins.str
    object: builtins.str
    predefined_acl: builtins.str
    @property
    def role_entity(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        bucket: builtins.str = ...,
        id: builtins.str = ...,
        object: builtins.str = ...,
        predefined_acl: builtins.str = ...,
        role_entity: collections.abc.Iterable[builtins.str] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bucket", b"bucket", "id", b"id", "object", b"object", "predefined_acl", b"predefined_acl", "resource_info", b"resource_info", "role_entity", b"role_entity"]) -> None: ...

global___StorageObjectAcl = StorageObjectAcl

@typing_extensions.final
class StorageTransferJobXScheduleXScheduleEndDate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DAY_FIELD_NUMBER: builtins.int
    MONTH_FIELD_NUMBER: builtins.int
    YEAR_FIELD_NUMBER: builtins.int
    day: builtins.float
    month: builtins.float
    year: builtins.float
    def __init__(
        self,
        *,
        day: builtins.float = ...,
        month: builtins.float = ...,
        year: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["day", b"day", "month", b"month", "year", b"year"]) -> None: ...

global___StorageTransferJobXScheduleXScheduleEndDate = StorageTransferJobXScheduleXScheduleEndDate

@typing_extensions.final
class StorageTransferJobXScheduleXScheduleStartDate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DAY_FIELD_NUMBER: builtins.int
    MONTH_FIELD_NUMBER: builtins.int
    YEAR_FIELD_NUMBER: builtins.int
    day: builtins.float
    month: builtins.float
    year: builtins.float
    def __init__(
        self,
        *,
        day: builtins.float = ...,
        month: builtins.float = ...,
        year: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["day", b"day", "month", b"month", "year", b"year"]) -> None: ...

global___StorageTransferJobXScheduleXScheduleStartDate = StorageTransferJobXScheduleXScheduleStartDate

@typing_extensions.final
class StorageTransferJobXScheduleXStartTimeOfDay(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOURS_FIELD_NUMBER: builtins.int
    MINUTES_FIELD_NUMBER: builtins.int
    NANOS_FIELD_NUMBER: builtins.int
    SECONDS_FIELD_NUMBER: builtins.int
    hours: builtins.float
    minutes: builtins.float
    nanos: builtins.float
    seconds: builtins.float
    def __init__(
        self,
        *,
        hours: builtins.float = ...,
        minutes: builtins.float = ...,
        nanos: builtins.float = ...,
        seconds: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["hours", b"hours", "minutes", b"minutes", "nanos", b"nanos", "seconds", b"seconds"]) -> None: ...

global___StorageTransferJobXScheduleXStartTimeOfDay = StorageTransferJobXScheduleXStartTimeOfDay

@typing_extensions.final
class StorageTransferJobXSchedule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REPEAT_INTERVAL_FIELD_NUMBER: builtins.int
    SCHEDULE_END_DATE_FIELD_NUMBER: builtins.int
    SCHEDULE_START_DATE_FIELD_NUMBER: builtins.int
    START_TIME_OF_DAY_FIELD_NUMBER: builtins.int
    repeat_interval: builtins.str
    @property
    def schedule_end_date(self) -> global___StorageTransferJobXScheduleXScheduleEndDate: ...
    @property
    def schedule_start_date(self) -> global___StorageTransferJobXScheduleXScheduleStartDate: ...
    @property
    def start_time_of_day(self) -> global___StorageTransferJobXScheduleXStartTimeOfDay: ...
    def __init__(
        self,
        *,
        repeat_interval: builtins.str = ...,
        schedule_end_date: global___StorageTransferJobXScheduleXScheduleEndDate | None = ...,
        schedule_start_date: global___StorageTransferJobXScheduleXScheduleStartDate | None = ...,
        start_time_of_day: global___StorageTransferJobXScheduleXStartTimeOfDay | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["schedule_end_date", b"schedule_end_date", "schedule_start_date", b"schedule_start_date", "start_time_of_day", b"start_time_of_day"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["repeat_interval", b"repeat_interval", "schedule_end_date", b"schedule_end_date", "schedule_start_date", b"schedule_start_date", "start_time_of_day", b"start_time_of_day"]) -> None: ...

global___StorageTransferJobXSchedule = StorageTransferJobXSchedule

@typing_extensions.final
class StorageTransferJobXTransferSpecXAwsS3DataSourceXAwsAccessKey(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCESS_KEY_ID_FIELD_NUMBER: builtins.int
    SECRET_ACCESS_KEY_FIELD_NUMBER: builtins.int
    access_key_id: builtins.str
    secret_access_key: builtins.str
    def __init__(
        self,
        *,
        access_key_id: builtins.str = ...,
        secret_access_key: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["access_key_id", b"access_key_id", "secret_access_key", b"secret_access_key"]) -> None: ...

global___StorageTransferJobXTransferSpecXAwsS3DataSourceXAwsAccessKey = StorageTransferJobXTransferSpecXAwsS3DataSourceXAwsAccessKey

@typing_extensions.final
class StorageTransferJobXTransferSpecXAwsS3DataSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUCKET_NAME_FIELD_NUMBER: builtins.int
    ROLE_ARN_FIELD_NUMBER: builtins.int
    AWS_ACCESS_KEY_FIELD_NUMBER: builtins.int
    bucket_name: builtins.str
    role_arn: builtins.str
    @property
    def aws_access_key(self) -> global___StorageTransferJobXTransferSpecXAwsS3DataSourceXAwsAccessKey: ...
    def __init__(
        self,
        *,
        bucket_name: builtins.str = ...,
        role_arn: builtins.str = ...,
        aws_access_key: global___StorageTransferJobXTransferSpecXAwsS3DataSourceXAwsAccessKey | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["aws_access_key", b"aws_access_key"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["aws_access_key", b"aws_access_key", "bucket_name", b"bucket_name", "role_arn", b"role_arn"]) -> None: ...

global___StorageTransferJobXTransferSpecXAwsS3DataSource = StorageTransferJobXTransferSpecXAwsS3DataSource

@typing_extensions.final
class StorageTransferJobXTransferSpecXAzureBlobStorageDataSourceXAzureCredentials(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SAS_TOKEN_FIELD_NUMBER: builtins.int
    sas_token: builtins.str
    def __init__(
        self,
        *,
        sas_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["sas_token", b"sas_token"]) -> None: ...

global___StorageTransferJobXTransferSpecXAzureBlobStorageDataSourceXAzureCredentials = StorageTransferJobXTransferSpecXAzureBlobStorageDataSourceXAzureCredentials

@typing_extensions.final
class StorageTransferJobXTransferSpecXAzureBlobStorageDataSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTAINER_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    STORAGE_ACCOUNT_FIELD_NUMBER: builtins.int
    AZURE_CREDENTIALS_FIELD_NUMBER: builtins.int
    container: builtins.str
    path: builtins.str
    storage_account: builtins.str
    @property
    def azure_credentials(self) -> global___StorageTransferJobXTransferSpecXAzureBlobStorageDataSourceXAzureCredentials: ...
    def __init__(
        self,
        *,
        container: builtins.str = ...,
        path: builtins.str = ...,
        storage_account: builtins.str = ...,
        azure_credentials: global___StorageTransferJobXTransferSpecXAzureBlobStorageDataSourceXAzureCredentials | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["azure_credentials", b"azure_credentials"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["azure_credentials", b"azure_credentials", "container", b"container", "path", b"path", "storage_account", b"storage_account"]) -> None: ...

global___StorageTransferJobXTransferSpecXAzureBlobStorageDataSource = StorageTransferJobXTransferSpecXAzureBlobStorageDataSource

@typing_extensions.final
class StorageTransferJobXTransferSpecXGcsDataSink(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUCKET_NAME_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    bucket_name: builtins.str
    path: builtins.str
    def __init__(
        self,
        *,
        bucket_name: builtins.str = ...,
        path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bucket_name", b"bucket_name", "path", b"path"]) -> None: ...

global___StorageTransferJobXTransferSpecXGcsDataSink = StorageTransferJobXTransferSpecXGcsDataSink

@typing_extensions.final
class StorageTransferJobXTransferSpecXGcsDataSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUCKET_NAME_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    bucket_name: builtins.str
    path: builtins.str
    def __init__(
        self,
        *,
        bucket_name: builtins.str = ...,
        path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bucket_name", b"bucket_name", "path", b"path"]) -> None: ...

global___StorageTransferJobXTransferSpecXGcsDataSource = StorageTransferJobXTransferSpecXGcsDataSource

@typing_extensions.final
class StorageTransferJobXTransferSpecXHttpDataSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LIST_URL_FIELD_NUMBER: builtins.int
    list_url: builtins.str
    def __init__(
        self,
        *,
        list_url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["list_url", b"list_url"]) -> None: ...

global___StorageTransferJobXTransferSpecXHttpDataSource = StorageTransferJobXTransferSpecXHttpDataSource

@typing_extensions.final
class StorageTransferJobXTransferSpecXObjectConditions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXCLUDE_PREFIXES_FIELD_NUMBER: builtins.int
    INCLUDE_PREFIXES_FIELD_NUMBER: builtins.int
    MAX_TIME_ELAPSED_SINCE_LAST_MODIFICATION_FIELD_NUMBER: builtins.int
    MIN_TIME_ELAPSED_SINCE_LAST_MODIFICATION_FIELD_NUMBER: builtins.int
    @property
    def exclude_prefixes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def include_prefixes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    max_time_elapsed_since_last_modification: builtins.str
    min_time_elapsed_since_last_modification: builtins.str
    def __init__(
        self,
        *,
        exclude_prefixes: collections.abc.Iterable[builtins.str] | None = ...,
        include_prefixes: collections.abc.Iterable[builtins.str] | None = ...,
        max_time_elapsed_since_last_modification: builtins.str = ...,
        min_time_elapsed_since_last_modification: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["exclude_prefixes", b"exclude_prefixes", "include_prefixes", b"include_prefixes", "max_time_elapsed_since_last_modification", b"max_time_elapsed_since_last_modification", "min_time_elapsed_since_last_modification", b"min_time_elapsed_since_last_modification"]) -> None: ...

global___StorageTransferJobXTransferSpecXObjectConditions = StorageTransferJobXTransferSpecXObjectConditions

@typing_extensions.final
class StorageTransferJobXTransferSpecXPosixDataSink(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ROOT_DIRECTORY_FIELD_NUMBER: builtins.int
    root_directory: builtins.str
    def __init__(
        self,
        *,
        root_directory: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["root_directory", b"root_directory"]) -> None: ...

global___StorageTransferJobXTransferSpecXPosixDataSink = StorageTransferJobXTransferSpecXPosixDataSink

@typing_extensions.final
class StorageTransferJobXTransferSpecXPosixDataSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ROOT_DIRECTORY_FIELD_NUMBER: builtins.int
    root_directory: builtins.str
    def __init__(
        self,
        *,
        root_directory: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["root_directory", b"root_directory"]) -> None: ...

global___StorageTransferJobXTransferSpecXPosixDataSource = StorageTransferJobXTransferSpecXPosixDataSource

@typing_extensions.final
class StorageTransferJobXTransferSpecXTransferOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DELETE_OBJECTS_FROM_SOURCE_AFTER_TRANSFER_FIELD_NUMBER: builtins.int
    DELETE_OBJECTS_UNIQUE_IN_SINK_FIELD_NUMBER: builtins.int
    OVERWRITE_OBJECTS_ALREADY_EXISTING_IN_SINK_FIELD_NUMBER: builtins.int
    delete_objects_from_source_after_transfer: builtins.bool
    delete_objects_unique_in_sink: builtins.bool
    overwrite_objects_already_existing_in_sink: builtins.bool
    def __init__(
        self,
        *,
        delete_objects_from_source_after_transfer: builtins.bool = ...,
        delete_objects_unique_in_sink: builtins.bool = ...,
        overwrite_objects_already_existing_in_sink: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["delete_objects_from_source_after_transfer", b"delete_objects_from_source_after_transfer", "delete_objects_unique_in_sink", b"delete_objects_unique_in_sink", "overwrite_objects_already_existing_in_sink", b"overwrite_objects_already_existing_in_sink"]) -> None: ...

global___StorageTransferJobXTransferSpecXTransferOptions = StorageTransferJobXTransferSpecXTransferOptions

@typing_extensions.final
class StorageTransferJobXTransferSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AWS_S3_DATA_SOURCE_FIELD_NUMBER: builtins.int
    AZURE_BLOB_STORAGE_DATA_SOURCE_FIELD_NUMBER: builtins.int
    GCS_DATA_SINK_FIELD_NUMBER: builtins.int
    GCS_DATA_SOURCE_FIELD_NUMBER: builtins.int
    HTTP_DATA_SOURCE_FIELD_NUMBER: builtins.int
    OBJECT_CONDITIONS_FIELD_NUMBER: builtins.int
    POSIX_DATA_SINK_FIELD_NUMBER: builtins.int
    POSIX_DATA_SOURCE_FIELD_NUMBER: builtins.int
    TRANSFER_OPTIONS_FIELD_NUMBER: builtins.int
    @property
    def aws_s3_data_source(self) -> global___StorageTransferJobXTransferSpecXAwsS3DataSource: ...
    @property
    def azure_blob_storage_data_source(self) -> global___StorageTransferJobXTransferSpecXAzureBlobStorageDataSource: ...
    @property
    def gcs_data_sink(self) -> global___StorageTransferJobXTransferSpecXGcsDataSink: ...
    @property
    def gcs_data_source(self) -> global___StorageTransferJobXTransferSpecXGcsDataSource: ...
    @property
    def http_data_source(self) -> global___StorageTransferJobXTransferSpecXHttpDataSource: ...
    @property
    def object_conditions(self) -> global___StorageTransferJobXTransferSpecXObjectConditions: ...
    @property
    def posix_data_sink(self) -> global___StorageTransferJobXTransferSpecXPosixDataSink: ...
    @property
    def posix_data_source(self) -> global___StorageTransferJobXTransferSpecXPosixDataSource: ...
    @property
    def transfer_options(self) -> global___StorageTransferJobXTransferSpecXTransferOptions: ...
    def __init__(
        self,
        *,
        aws_s3_data_source: global___StorageTransferJobXTransferSpecXAwsS3DataSource | None = ...,
        azure_blob_storage_data_source: global___StorageTransferJobXTransferSpecXAzureBlobStorageDataSource | None = ...,
        gcs_data_sink: global___StorageTransferJobXTransferSpecXGcsDataSink | None = ...,
        gcs_data_source: global___StorageTransferJobXTransferSpecXGcsDataSource | None = ...,
        http_data_source: global___StorageTransferJobXTransferSpecXHttpDataSource | None = ...,
        object_conditions: global___StorageTransferJobXTransferSpecXObjectConditions | None = ...,
        posix_data_sink: global___StorageTransferJobXTransferSpecXPosixDataSink | None = ...,
        posix_data_source: global___StorageTransferJobXTransferSpecXPosixDataSource | None = ...,
        transfer_options: global___StorageTransferJobXTransferSpecXTransferOptions | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["aws_s3_data_source", b"aws_s3_data_source", "azure_blob_storage_data_source", b"azure_blob_storage_data_source", "gcs_data_sink", b"gcs_data_sink", "gcs_data_source", b"gcs_data_source", "http_data_source", b"http_data_source", "object_conditions", b"object_conditions", "posix_data_sink", b"posix_data_sink", "posix_data_source", b"posix_data_source", "transfer_options", b"transfer_options"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["aws_s3_data_source", b"aws_s3_data_source", "azure_blob_storage_data_source", b"azure_blob_storage_data_source", "gcs_data_sink", b"gcs_data_sink", "gcs_data_source", b"gcs_data_source", "http_data_source", b"http_data_source", "object_conditions", b"object_conditions", "posix_data_sink", b"posix_data_sink", "posix_data_source", b"posix_data_source", "transfer_options", b"transfer_options"]) -> None: ...

global___StorageTransferJobXTransferSpec = StorageTransferJobXTransferSpec

@typing_extensions.final
class StorageTransferJob(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATION_TIME_FIELD_NUMBER: builtins.int
    DELETION_TIME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LAST_MODIFICATION_TIME_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    SCHEDULE_FIELD_NUMBER: builtins.int
    TRANSFER_SPEC_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    creation_time: builtins.str
    deletion_time: builtins.str
    description: builtins.str
    id: builtins.str
    last_modification_time: builtins.str
    name: builtins.str
    project: builtins.str
    status: builtins.str
    @property
    def schedule(self) -> global___StorageTransferJobXSchedule: ...
    @property
    def transfer_spec(self) -> global___StorageTransferJobXTransferSpec: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        creation_time: builtins.str = ...,
        deletion_time: builtins.str = ...,
        description: builtins.str = ...,
        id: builtins.str = ...,
        last_modification_time: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        status: builtins.str = ...,
        schedule: global___StorageTransferJobXSchedule | None = ...,
        transfer_spec: global___StorageTransferJobXTransferSpec | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "schedule", b"schedule", "transfer_spec", b"transfer_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["creation_time", b"creation_time", "deletion_time", b"deletion_time", "description", b"description", "id", b"id", "last_modification_time", b"last_modification_time", "name", b"name", "project", b"project", "resource_info", b"resource_info", "schedule", b"schedule", "status", b"status", "transfer_spec", b"transfer_spec"]) -> None: ...

global___StorageTransferJob = StorageTransferJob
